lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [thread-next>] [day] [month] [year] [list]
Date:   Fri, 14 Sep 2018 16:14:27 +0530
From:   Harshit Jain <harshitjain6751@...il.com>
To:     unlisted-recipients:; (no To-header on input)
Cc:     stable@...r.kernel.org, Harshit Jain <dev-harsh1998@...mail.com>,
        Tony Finch <dot@...at.at>, linux-kernel@...r.kernel.org
Subject: [PATCH] scripts: unifdef: fix stringop-truncation warning

From: Harshit Jain <dev-harsh1998@...mail.com>

* This commit resolves the following warning when the mainline kernel is build with the android environment.

-> warning :-> https://gist.github.com/dev-harsh1998/757427b16a58f5498db3d87212a9651b

* This warning is persistant in all the currently maintained android kernel i.e 3.18, 4.4, 4.9, 4.14.

Signed-off-by: Harshit Jain <dev-harsh1998@...mail.com>
---
 scripts/unifdef.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/scripts/unifdef.c b/scripts/unifdef.c
index 7493c0ee51cc..4ce008eda362 100644
--- a/scripts/unifdef.c
+++ b/scripts/unifdef.c
@@ -395,8 +395,8 @@ usage(void)
  * When we have processed a group that starts off with a known-false
  * #if/#elif sequence (which has therefore been deleted) followed by a
  * #elif that we don't understand and therefore must keep, we edit the
  * latter into a #if to keep the nesting correct. We use strncpy() to
  * overwrite the 4 byte token "elif" with "if  " without a '\0' byte.
  *
  * When we find a true #elif in a group, the following block will
  * always be kept and the rest of the sequence after the next #elif or
@@ -450,7 +450,7 @@ static void Idrop (void) { Fdrop();  ignoreon(); }
 static void Itrue (void) { Ftrue();  ignoreon(); }
 static void Ifalse(void) { Ffalse(); ignoreon(); }
 /* modify this line */
-static void Mpass (void) { strncpy(keyword, "if  ", 4); Pelif(); }
+static void Mpass (void) { memcpy(keyword, "if  ", 4); Pelif(); }
 static void Mtrue (void) { keywordedit("else");  state(IS_TRUE_MIDDLE); }
 static void Melif (void) { keywordedit("endif"); state(IS_FALSE_TRAILER); }
 static void Melse (void) { keywordedit("endif"); state(IS_FALSE_ELSE); }
@@ -395,8 +395,8 @@ usage(void)
  * #if/#elif sequence (which has therefore been deleted) followed by a
  * #elif that we don't understand and therefore must keep, we edit the
- * latter into a #if to keep the nesting correct. We use strncpy() to
- * overwrite the 4 byte token "elif" with "if  " without a '\0' byte.
+ * latter into a #if to keep the nesting correct. We use the memcpy() 
+ * from the string header overwrite the 4 byte token "elif" with "if  ".
  *
  * When we find a true #elif in a group, the following block will
-- 
2.18.0

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ